package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````H"4```````!``````````$BQ````
M`````````$``.``-`$``'``;``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````$`9````````0!D`````````
M$`````````$````%`````"``````````(``````````@````````]3P`````
M``#U/``````````0`````````0````0`````8`````````!@`````````&``
M``````#H1P```````.A'`````````!`````````!````!@```.BK````````
MZ+L```````#HNP```````$`$````````L`0`````````$`````````(````&
M````^*L```````#XNP```````/B[``````````(``````````@````````@`
M````````!`````0````X`P```````#@#````````.`,````````@````````
M`"``````````"``````````$````!````%@#````````6`,```````!8`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````(``````````@``````````@`````````4.5T9`0`
M``"@H````````*"@````````H*````````#T`````````/0`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````Z*L```````#HNP```````.B[````
M````&`0````````8!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````$`````4```!'3E4``H``P`0````!````````
M``0````4`````P```$=.50#?MM@#<&IKYE)RI+N(SXQ$RCQ\P`0````0````
M`0```$=.50```````P````(``````````````!$````^````!`````@````@
M'!``!4`$AB@"``2`A@"$@@D`($D@!`B8@!%!N@`""@`````^````00```$0`
M``!%````3````$T```!/`````````%(```!3````5````%8```!8````6@``
M````````````;L7?'\[>1RUK?YI\+L6;MM1DU'PA_^0.V7%8'.)'Q@&R`8MO
MK$OCP$+ZUX?"Y3\LNN.2?/NA;&!K"4/69J_,9L6YG$`X\HL<0D75[(D'<-,S
M8MOM%8PES`PZEPNGW:-K?JF<F]%ESFW@IP(*:QJ>4`J*$%>CX/M)````````
M`````````````````````````````.0````2````````````````````````
M`)8````2`````````````````````````%T!```2````````````````````
M`````%<"```2`````````````````````````"@"```2````````````````
M`````````/H````2``````````````````````````$````@````````````
M`````````````)<!```2`````````````````````````+L"```2````````
M`````````````````/`!```2`````````````````````````*D"```2````
M`````````````````````'0!```2`````````````````````````"L!```2
M`````````````````````````!L!```2`````````````````````````,T!
M```2`````````````````````````.H!```2````````````````````````
M``T!```2``````````````````````````("```2````````````````````
M`````&<#```2`````````````````````````!`````@````````````````
M`````````'L!```2`````````````````````````.D````2````````````
M`````````````.,!```2`````````````````````````"P````@````````
M`````````````````#<"```2`````````````````````````'0"```2````
M`````````````````````$8````2`````````````````````````&,````6
M`````````````````````````$T!```2`````````````````````````'8`
M```2`````````````````````````-,````2````````````````````````
M`(<````2`````````````````````````,4!```2````````````````````
M`````+X!```2`````````````````````````/4!```2````````````````
M`````````+<````2``````````````````````````D"```2````````````
M`````````````-0!```2`````````````````````````&T"```2````````
M`````````````````#\!```2`````````````````````````)@"```2````
M`````````````````````*X!```2`````````````````````````.X````2
M`````````````````````````(8!```2`````````````````````````)$"
M```2`````````````````````````-P!```2````````````````````````
M`#8"```2`````````````````````````'P"```2````````````````````
M`````*(````2`````````````````````````&@!```2````````````````
M`````````)P!```2`````````````````````````+4!```2````````````
M`````````````!H"```2`````````````````````````(,"```2````````
M`````````````````!("```2`````````````````````````#0!```2````
M`````````````````````%0````2`````````````````````````#X"```2
M`````````````````````````(H"```2`````````````````````````*0!
M```2`````````````````````````/P!```2````````````````````````
M`'`#```2``\`4$$```````#;`````````,4#```2``\`0#@```````#H!@``
M`````$L"```2``\`D",````````&`@```````.<"```2``\`L"X````````%
M``````````4#```2``\`,#\````````@`@```````.L#```2``\`P"X`````
M```"`@```````*L#```0`!D`*,```````````````````/@"```2``\`T#``
M```````B`````````!L#```2``\`H#8```````!A`````````'P#```1`!$`
M`&`````````$`````````)@#```2``\`\%@```````"?`0```````*,#```2
M``\`P"T````````E`````````,`#```0`!D`F,```````````````````-D#
M```2``\`,#<````````+`0```````(L#```0`!@``,``````````````````
M`#\#```2``\``#$````````Q`0```````+$"```1`!D`0,`````````(````
M`````%`"```1`!D`8,`````````(`````````-(#```0`!@`*,``````````
M`````````/@#```1`!@`(,`````````(`````````)$#```2``\`H"4`````
M```B`````````+<#```2``\`H%@```````!%`````````(T#```@`!@``,``
M`````````````````+,"```A`!D`0,`````````(`````````%4#```2``\`
M$#<````````=`````````%X"```B`````````````````````````"D#```2
M``\`\"T```````"Y`````````$L#```2``\`D%H```````!+`@```````,8`
M```1`!D`<,`````````!``````````($```2``\`0#(```````!<!```````
M``!?7V=M;VY?<W1A<G1?7P!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`
M7TE435]R96=I<W1E<E1-0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?
M<WES7VEN:70S`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L7V%T9F]R:U]L;V-K
M`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT
M97AT`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L
M86=S`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U;FQO8VL`
M4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]N
M97=84P!P97)L7V1E<W1R=6-T`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E
M`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%]?<W1A8VM?8VAK7V9A
M:6P`97AI=`!L<V5E:S8T`')E861D:7(V-`!S=')D=7``8VQO<V5D:7(`;W!E
M;C8T`'-T<G)C:'(`=6YL:6YK`&UE;6UO=F4`<W1R=&]K`'-T<FQE;@!R;61I
M<@!R96%D`'-T<G-T<@!M:V1I<@!G971P:60`<F5A9&QI;FL`<F5A;&QO8P!?
M7W-P<FEN=&9?8VAK`%]?9G!R:6YT9E]C:&L`;'-T870V-`!?7VQI8F-?<W1A
M<G1?;6%I;@!S=&1E<G(`;65M8VAR`%]?8WAA7V9I;F%L:7IE`'-T<F-H<@!O
M<&5N9&ER`&=E='5I9`!A8V-E<W,`;65M8W!Y`'-T<F-M<`!?7V5R<FYO7VQO
M8V%T:6]N`'-T<FYC;7``7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`&QI
M8G!E<FPN<V\N-2XS-@!L:6)C+G-O+C8`<&%R7V-U<G)E;G1?97AE8P!P87)?
M8F%S96YA;64`6%-?26YT97)N86QS7U!!4E]"3T]4`'!A<E]E;G9?8VQE86X`
M<&%R7V-U<G)E;G1?97AE8U]P<F]C`'!A<E]D:7)N86UE`'-H85]F:6YA;`!G
M971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?24]?<W1D
M:6Y?=7-E9`!?7V1A=&%?<W1A<G0`<VAA7W5P9&%T90!X<U]I;FET`%]?8G-S
M7W-T87)T`'-H85]I;FET`%]E;F0`<&%R7VUK=&UP9&ER`%]E9&%T80!P87)?
M<V5T=7!?;&EB<&%T:`!P87)?9FEN9'!R;V<`;7E?<&%R7W!L`'!A<E]I;FET
M7V5N=@!'3$E"0U\R+C$T`$=,24)#7S(N,S0`1TQ)0D-?,BXT`$=,24)#7S(N
M,S,`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXS+C0`1TQ)0D-?,BXR+C4````!``$`
M`0`"``,``0`!``(`!``"``(``@`!``$``@`"``$``@`"``$``0`"``(``0`%
M``(``0`!``$``0`!``$``@`"``(``0`"``(``@`!``(``@`!``8``@`"``4`
M`@`!``$``@`"``,``@`"``$``0`'``@``@`"``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``@`"``$``0`!``$``0`"``$``@`!``$``0`!````
M`0`'`-T"```0`````````)21E@8```@`#P0``!````"TD98&```'`!H$```0
M````%&EI#0``!@`E!```$````+.1E@8```4`+P0``!````!R&6D)```$`#H$
M```0````=!EI"0```P!&!```$````'4::0D```(`4@0```````#HNP``````
M``@`````````@"8```````#PNP````````@`````````0"8````````(P```
M``````@`````````",`````````@P`````````@`````````V&(```````"X
MOP````````8````&``````````````#`OP````````8````'````````````
M``#(OP````````8````4``````````````#0OP````````8````8````````
M``````#8OP````````8```!7``````````````#@OP```````!(````<````
M``````````#HOP````````8````=``````````````#POP````````8````>
M``````````````#XOP````````8````Z``````````````!`P`````````4`
M``!.``````````````!@P`````````4```!/``````````````!PP```````
M``4```!:```````````````0O@````````<````!```````````````8O@``
M``````<````"```````````````@O@````````<````#```````````````H
MO@````````<````$```````````````PO@````````<````%````````````
M```XO@````````<````(``````````````!`O@````````<````)````````
M``````!(O@````````<````*``````````````!0O@````````<````+````
M``````````!8O@````````<````,``````````````!@O@````````<````-
M``````````````!HO@````````<````.``````````````!PO@````````<`
M```/``````````````!XO@````````<````0``````````````"`O@``````
M``<````1``````````````"(O@````````<````2``````````````"0O@``
M``````<````3``````````````"8O@````````<````5``````````````"@
MO@````````<````6``````````````"HO@````````<````7````````````
M``"PO@````````<````9``````````````"XO@````````<````:````````
M``````#`O@````````<````;``````````````#(O@````````<````?````
M``````````#0O@````````<````@``````````````#8O@````````<````A
M``````````````#@O@````````<````B``````````````#HO@````````<`
M```C``````````````#PO@````````<````D``````````````#XO@``````
M``<````E````````````````OP````````<````F```````````````(OP``
M``````<````G```````````````0OP````````<````H```````````````8
MOP````````<````I```````````````@OP````````<````J````````````
M```HOP````````<````K```````````````POP````````<````L````````
M```````XOP````````<````M``````````````!`OP````````<````N````
M``````````!(OP````````<````O``````````````!0OP````````<````P
M``````````````!8OP````````<````Q``````````````!@OP````````<`
M```R``````````````!HOP````````<````S``````````````!POP``````
M``<````T``````````````!XOP````````<````U``````````````"`OP``
M``````<````V``````````````"(OP````````<````W``````````````"0
MOP````````<````X``````````````"8OP````````<````Y````````````
M``"@OP````````<````[``````````````"HOP````````<````\````````
M``````"POP````````<````]````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!(@^P(2(L%M9\``$B%P'0"_]!(@\0(PP```````````/\UVIT``/\EW)T`
M``\?0`#_)=J=``!H`````.G@_____R72G0``:`$```#IT/____\ERIT``&@"
M````Z<#_____)<*=``!H`P```.FP_____R6ZG0``:`0```#IH/____\ELIT`
M`&@%````Z9#_____):J=``!H!@```.F`_____R6BG0``:`<```#I</____\E
MFIT``&@(````Z6#_____)9*=``!H"0```.E0_____R6*G0``:`H```#I0/__
M__\E@IT``&@+````Z3#_____)7J=``!H#````.D@_____R5RG0``:`T```#I
M$/____\E:IT``&@.````Z0#_____)6*=``!H#P```.GP_O___R5:G0``:!``
M``#IX/[___\E4IT``&@1````Z=#^____)4J=``!H$@```.G`_O___R5"G0``
M:!,```#IL/[___\E.IT``&@4````Z:#^____)3*=``!H%0```.F0_O___R4J
MG0``:!8```#I@/[___\E(IT``&@7````Z7#^____)1J=``!H&````.E@_O__
M_R42G0``:!D```#I4/[___\E"IT``&@:````Z4#^____)0*=``!H&P```.DP
M_O___R7ZG```:!P```#I(/[___\E\IP``&@=````Z1#^____)>J<``!H'@``
M`.D`_O___R7BG```:!\```#I\/W___\EVIP``&@@````Z>#]____)=*<``!H
M(0```.G0_?___R7*G```:"(```#IP/W___\EPIP``&@C````Z;#]____);J<
M``!H)````.F@_?___R6RG```:"4```#ID/W___\EJIP``&@F````Z8#]____
M):*<``!H)P```.EP_?___R6:G```:"@```#I8/W___\EDIP``&@I````Z5#]
M____)8J<``!H*@```.E`_?___R6"G```:"L```#I,/W___\E>IP``&@L````
MZ2#]____)7*<``!H+0```.D0_?___R5JG```:"X```#I`/W___\E8IP``&@O
M````Z?#\____)5J<``!H,````.G@_/___R52G```:#$```#IT/S___\E2IP`
M`&@R````Z<#\____)4*<``!H,P```.FP_/___R4ZG```:#0```#IH/S___\E
M4IP``&:0``````````!54TB#[#B)?"0<2(U\)!Q(B70D$$B-="002(E4)`A(
MC50D"&1(BP0E*````$B)1"0H,<#H>/___TB+->F;``!(BST:G```2(GRZ`(Y
M``"`/8N<````#X05`0``2(L%[IL``&1(BP"`B"H$```#BT0D'(UX!(U8`TAC
M_TC!YP/HO?[__TB+?"001(M$)!Q(B<%(B05AG```2(L'2(D!2(T%CST``$B)
M00A(BP7AFP``2(E!$$B-!7P]``!(B4$808/X`0^.)0$``$B#QPA!@\`#N@0`
M```/'P!(BP=(8_*#P@%(@\<(2(D$\40YPG7J2&/22(L]")P``$4QP$B--=X(
M``!(QP31`````(G:Z*_[__^)PX7`#X2%````2(L]WIL``$B-;"0DZ'3]__\Q
MP$B)[DB-/=L[``#HPP$``$B%P'1Q2(L]MYL``.A2^___Z*W\__](BT0D*&1(
M*P0E*`````^%F@```$B#Q#B)V%M=P^@[_/__2(D%A)L``$B)QTB%P'1SZ)?\
M__](BP7`F@``9$B+$,:"UPD```#IPO[__TB+/5F;``#HE/O__XG#Z6C___](
MBSTVFP``2(7_=`KH_!L``.EY____2(T]^#H``$B)[N@H`0``2(D%$9L``$B)
MQTB%P`^$5____^O2N@0```#I]_[__[\!````Z._Z___HVOS__V8N#Q^$````
M```Q[4F)T5Y(B>)(@^3P4%1%,<`QR4B-/=7]____%3>:``#T9BX/'X0`````
M``\?0`!(C3U1F@``2(T%2IH``$@Y^'052(L%WID``$B%P'0)_^`/'X``````
MPP\?@`````!(C3TAF@``2(TU&IH``$@I_DB)\$C![C](P?@#2`'&2-'^=!1(
MBP6EF0``2(7`=`C_X&8/'T0``,,/'X``````\P\>^H`])IH```!U*U5(@SV"
MF0```$B)Y70,2(L]IID``.@9_?__Z&3____&!?Z9```!7<,/'P###Q^`````
M`/,/'OKI=____P\?@`````!!5T%6055!5%532(/L"$B%_P^$L0```$R+-9*9
M``!-A?8/A*$````/M@=)B?])B?6$P'0$/#UU6$4QY$F+'DB%VW0S36/D3(GU
M#Q^``````$R)XDR)_DB)W^C"^?__A<!U!T*`/",]=$=(BUT(2(/%"$B%VW7:
M2(/$"$B)V%M=05Q!74%>05_##Q^$``````!)B?Q!#[9$)`%)@\0!A,!T!#P]
M=>Y%*?SKD68/'T0``$PI]4J-7",!2,']`T&);0#KM&8/'T0``#';ZZH/'T``
M4TB)^TB![*````!D2(L$)2@```!(B80DF````#'`2(GFZ!K[__^%P'4VBU0D
M&('B`/```('Z`$```'0(@?H`H```=1Z^`@```$B)W^A?^___A<`/E,`/ML#K
M!P\?1```,<!(BY0DF````&1(*Q0E*````'4)2('$H````%O#Z(WZ__]F9BX/
M'X0``````&:0055!5%532('LJ````&1(BP0E*````$B)A"28````,<!(A?]T
M"(`_`$B)^W4K2(N$))@```!D2"L$)2@````/A2,!``!(@<2H````6UU!7$%=
MPV8/'T0``.@S^?__2(G%2(7`=,A(B>_H`_O__TB%P`^$L@```(!X$RY,C6`3
M=1!!@'PD`0!TW0\?A```````@'@3+@^$I@```$B)W^C.^/__3(GG28G%Z,/X
M__]!C7P%`DAC_^@6^/__38GA28G8O@$```!)B<5(B<<QP$C'PO____](C0TY
M-P``Z##Z__],B>](B>;HE?C__TR)[X/X_W00BT0D&"4`\```/0!```!T7>CX
M]___3(GOZ%#X__](B>_H6/K__TB%P`^%5?___P\?@`````!(B>_HT/G__TB)
MW^C8]___Z?#^__\/'P!!@'PD`2X/A4[___]!@'PD`@`/A`W____I/?___P\?
M`.B;_O__ZZ'H%/G__P\?0`!!5+H"````,?9!B?Q54TB![!```0!D2(L$)2@`
M``!(B80D"``!`#'`2(GCZ%#Y__](C6C_2(GJ2,'Z/TC!ZC!(C405``^WP$@I
MT$@IQ0^(D0````\?1```,=)(B>Y$B>?H&_G__[H(``$`2(G>1(GGZ,OV__](
MF$B#^`=V4TB-1`/X2#G8<DE(C14BE@``ZPE(@^@!2#G8<C=(BPI(.0AU[T@I
MV$@!Z$B+E"0(``$`9$@K%"4H````=3-(@<00``$`6UU!7,-F+@\?A```````
M2('M```!`$B!_0``__\/A73___](Q\#_____Z[KH'OC__V9F+@\?A```````
M#Q\`056Z_P\``$%454B)]5-(B?M(C3V2-0``2('L&!```&1(BP0E*````$B)
MA"0($```,<!)B>1,B>;H8_?__X7`?A*)P8/H`4ACT(`\%`!U287`=3U(BP4F
ME0``2(GJ2(G>9$B+..A']O__2(N$)`@0``!D2"L$)2@```!U3TB!Q!@0``!;
M74%<05W#9@\?1```B<%F#Q]$``!,8^F^+P```$R)YTR)ZNA5]?__2(7`=*-(
MBP7)E```3(GI3(GB2(G>9$B+..C']O__ZY[H0/?__T%7059!54%454B)]5-(
MB?M(@^P89$B+!"4H````2(E$)`@QP#'`@#X]#Y3`2`'%2(GOZ/GU__](C70D
M!$B)WTF)Q#'`Z!?[__](A<`/A`8!``!(B<=)B<7HT_7__TPYX`^#T@```$QC
M="0$2<'F`P^V`X3`#X2>`0``/#T/A)8!``!(B=@/'P`/ME`!2(/``832=`6`
M^CUU[T@IV$B83(LM:Y0``$J-?"`"Z.'T__]-`?5)B44`2(7`=%9(BP5.E```
M2(U+`4J+%#`/M@.(`H3`="(\/74-ZQP/'X``````A,!T$0^V`4B#P@%(@\$!
MB`(\/77KQ@(],<!F#Q]$```/MDP%`(A,`@%(@\`!A,EU[TB+1"0(9$@K!"4H
M````#X4'`0``2(/$&%M=05Q!74%>05_##Q]``#'`9@\?1```#[94!0!!B%0%
M`$B#P`&$TG7NZ[T/'T``3(L]L9,``$F#/P`/A+8```!,B?A%,>V02(/`"$2)
MZD&#Q0%(@S@`=>^-<@-(8_9(P>8#BP6WDP``A<!U6\<%J9,```$```!(B??H
MZ?/__TB%P`^$8?___TUC]4R)_DB)QTG!Y@-,B?+H&_7__TB)!423``!(B<%!
MC44!1(EL)`1(F$C'!,$`````Z8C^__]F#Q^$``````!,B?_H^/7__TB)!1&3
M``!(B<%(A<`/A`;___]-8_5)P>8#Z[L/'T``,<#I?_[__[X0````13'MZ5__
M___H#_7__V9F+@\?A```````#Q]``%-(BQUHD@``2(T-T7(``$B--9,R``!(
MBQ5;D@``9$B+.^B:]?__9$B+.T4QR5M,C07[,P``2(T5A!$``$R)P4B--7\R
M``#IY?/__P\?1```2(L%&9(``$B+%1J2``!(C0U[<@``2(TU/3(``&1(BSCI
M2_7__V9F+@\?A```````55-(@>PH(```9$B+!"4H````2(F$)!@@```QP$B)
MXTB-K"00$```Z`3S__^Z`1```$B)W[X!````08G`3(T-XC$``#'`2(T-#C(`
M`.B_]/__N@`0``!(B>Y(B=_HK_/__X7`>%"->`%(B<-(8__H7?+__TB%P'0]
M2&/;2(GN2(G'2(G:Z-?T___&!!@`2(G!2(N$)!@@``!D2"L$)2@```!U#4B!
MQ"@@``!(B<A;7</HR_/__S')Z]</'X``````Z3O___]F9BX/'X0``````$%7
M059!54%428G\2(T]AC$``%532(GS2('LN!```&1(BP0E*````$B)A"2H$```
M,<!(C70D#.B5]___OB\```!,B>=(B<7H%?/__TB%P'1`,<!,B>9(C3U%,0``
MZ`_\__],B>!(BY0DJ!```&1(*Q0E*`````^%@@$``$B!Q+@0``!;74%<05U!
M7D%?PP\?`$B)WTR-+10Q``!,C37Z,0``Z.KR__],B>Y(B<?H'_/__TB)PTB%
MP'27@#L`#X3D````9@\?1```2(7M=!-(B=Y(B>_HZ/+__X7`#X2G````2(G?
MZ+CQ__](C50#_TF)QT@YTW(7ZR5F#Q^$``````#&`@!(@^H!2#G3=`6`.B]T
M[TB)W^B'\?__28G'3(GGZ'SQ__])C40'`4@]_P\```^'&____TR-O"2@````
M3(GQ28G8,<!(@^P(N@`0``"^`0```$R)_T%43(T-43```.C<\O__2(UT)"!,
MB?_H/_'__UI9A<!U$(M$)"@E`/```#T`@```=$E,B>XQ_^@_\O__2(G#2(7`
M#X2S_O__@#L`#X4B____2(7M=`:`?0`N=!=!OP$```!(C1W8+P``Z5G___\/
M'T0``(!]`0!TN>OAO@$```!,B?_H<_+__X7`=:9,B?Y(C3VV+P``Z(#Z__],
MB?_HF/'__^EG_O__Z*[Q__]F9BX/'X0```````\?`%.^+P```$B)^^CB\/__
M2(U0`4B%P$@/1=I(B=];Z5[Q__]F9BX/'X0```````\?`%532('L&!```&1(
MBP0E*````$B)A"0($```,<!(A?\/A,L```"`/P!(B?L/A+\```#H*O#__TB-
M4`%(@?H`$```#X?A````2(GE2(GO@_H(<@Z)T4B)WL'I`_-(I4B)\S')]L($
M=`F+"XD/N00```#VP@)T#D0/MP0+9D2)!`](@\$"@^(!=`</MA0+B!0/2(U$
M!?](.<5R$^L6#Q]$``#&``!(@^@!2#GH=`6`."]T[[XO````2(GOZ`+P__](
MA<!T+4@YQ7)82(GOZ(#P__](BY0D"!```&1(*Q0E*````'5)2('$&!```%M=
MPP\?`$B+A"0($```9$@K!"4H````=2E(@<08$```2(T]12X``%M=Z3CP__\/
M'X0``````,8``.NC#Q\`,<#KI.@_\/__9F8N#Q^$```````/'T``05=!5D%5
M05152(TM(BX``%-(@^P89$B+!"4H````2(E$)`@QP$B-7"0$9@\?1```,<!(
MB=Y(B>_H$_3__TB%P'0V2&-4)`1(BP6RC0``2(T$T$B+4`A(B1!(A=)TTF:0
M2(M0$$B#P`A(B1!(A=)U\.N^9@\?1```2(TMO"T``)`QP$B)WDB)[^C#\___
M2(7`=#9(8U0D!$B+!6*-``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)
M$$B%TG7PZ[YF#Q]$``!(C2UT+0``D#'`2(G>2(GOZ'/S__](A<!T-DAC5"0$
M2(L%$HT``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/
M'T0``$B-+2TM``"0,<!(B=Y(B>_H(_/__TB%P'0V2&-4)`1(BP7"C```2(T$
MT$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U\.N^9@\?1```2(TMY"P`
M`)`QP$B)WDB)[^C3\O__2(7`=#9(8U0D!$B+!7*,``!(C0302(M0"$B)$$B%
MTG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!,C26D+```D#'`2(G>3(GG
MZ(/R__](A<!T-DAC5"0$2(L%(HP``$B-!-!(BU`(2(D02(72=-)FD$B+4!!(
M@\`(2(D02(72=?#KOF8/'T0``$R-)0DL``"0,<!(B=Y,B>?H,_+__TB%P'0V
M2&-4)`1(BP72BP``2(T$T$B+4`A(B1!(A=)TTF:02(M0$$B#P`A(B1!(A=)U
M\.N^9@\?1```3(TU$"P``)`QP$B)WDR)]^CC\?__2(7`=#9(8U0D!$B+!8*+
M``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)$$B%TG7PZ[YF#Q]$``!,
MC2W**P``D#'`2(G>3(GOZ)/Q__](A<!T-DAC5"0$2(L%,HL``$B-!-!(BU`(
M2(D02(72=-)FD$B+4!!(@\`(2(D02(72=?#KOF8/'T0``$R-/80K``"0,<!(
MB=Y,B?_H0_'__TB%P'0V2&-4)`1(BP7BB@``2(T$T$B+4`A(B1!(A=)TTF:0
M2(M0$$B#P`A(B1!(A=)U\.N^9@\?1```3(T]TBH``)`QP$B)WDR)_^CS\/__
M2(7`=#9(8U0D!$B+!9**``!(C0302(M0"$B)$$B%TG329I!(BU`02(/`"$B)
M$$B%TG7PZ[YF#Q]$``!(B=Y(C3WK*@``Z*GP__](A<!T#4B)QDR)[S'`Z#?U
M__\QP$B)WDB-/=DJ``#HAO#__TB%P'012(G&2(T]URH``#'`Z!#U__](B=Y(
MC3W1*@``,<#H7_#__TB)QDB%P'0Y3(GG,<#H[?3__TB+1"0(9$@K!"4H````
M=41(@\082(GO2(TUNRH``#'`6UU!7$%=05Y!7^F^]/__,<!(B=Y(C3V-*@``
MZ`WP__](A<!TNTB)QDR)]S'`Z)OT___KK.C4Z___#Q]``$B#[!A(C3T$*@``
M9$B+!"4H````2(E$)`@QP$B-="0$Z,OO__](A<!T+@^V$(#Z,`^4P(32#Y3"
M"="#\`$/ML!(BU0D"&1(*Q0E*````'4,2(/$&,,/'P`QP.ODZ&_K__]F9BX/
M'X0```````\?0`!(@^P(Z)?K__^)Q^@0ZO__2(7`=`-(BP!(@\0(PP\?`$%5
M051,C27C*0``54B)_4R)YU-(@^P89$B+!"4H````2(E$)`@QP$B-="0$Z"_O
M__](A<!T"(`X`$B)PW4R2(M$)`AD2"L$)2@````/A;0```!(B>Y(@\083(GG
M,<!;74%<05WIE_/__P\?@`````!(B>Y(B<?H->K__TB%P'0@2(M$)`AD2"L$
M)2@```!U=DB#Q!A;74%<05W##Q]$``!(B>_HB.G__TB)WTF)Q>A]Z?__28U\
M!0+HT^C__TB#[`A)B>B^`0```%-(Q\+_____2(G'28G%3(T-8"@``$B-#48I
M```QP.CDZO__6%I(BT0D"&1(*P0E*````'4(3(GNZ4_____H->K__P\?1```
M05=(C17L*```2(T-F2@``$%69D@/;L)(C16H*```28G^055(C3WN)P``0515
M4TB!['@!``!D2(L$)2@```!(B80D:`$``$B-!<DG``!(C6PD'$C'1"0P````
M`$C'A"2(`````````$B)[DC'1"10`````&9(#V[(2(T%>R@``&8/;,%F2`]N
MT$B-!7,H```/*40D(&9(#V[!9D@/;MA(C0UA*```9@]LPDB-!5LH```/$40D
M:&9(#V["9D@/;N`QP&8/;,,/$40D>&9(#V[!9@]LQ`\I1"1`Z'/M__](A<!T
M#(`X`$B)PP^%<@0``.A]Z?__B<?H]N?__TB%P`^$[0,``$R+($V%Y`^$X0,`
M`$R)Y^@)Z/__2(U\``'H7^?__T4/M@0D28G'2(G#183`=#Y,C2W<)P``#Q^$
M``````!%#[;`3(G_3(GIO@$```!(Q\+_____,<!)@\0!28/'`NA;Z?__10^V
M!"1%A,!UT4R-;"1@2(T]-2<``.L0#Q\`28M]"$F#Q0A(A?]T,TB)[C'`Z+GL
M__])B<1(A<!TX8`X`'3<2(G'Z'3M__^%P'303(GGZ%CH__])B<=(A<!U0$R-
M9"0@38L\)$V%_W0R08`_``^$"`,``$R)_^A`[?__A<`/A0`!``!-BWPD"$F#
MQ`A-A?]UV&8N#Q^$``````!,B?_H&.?__TB)WTF)Q.@-Y___18VD!`0$``!-
M8^1,B>?H6N;__U--B?A,C0W_)0``28G%2(T%YR8``+X!````2,?"_____U!(
MC0W*)@``3(GO,<#H9^C__TR)[[[``0``Z,KH__]?05B#^/]U$NB-Y___1(L(
M08/Y$0^%N0(``$B-M"20````3(GOZ-#G__^)PX7`='))BPY(BSV`A0``38GH
M,<!(C14D)P``O@$```#H>N7__T4QY$B+A"1H`0``9$@K!"4H````#X43!```
M2('$>`$``$R)X%M=05Q!74%>05_##Q\`3(G_28/$".@<Y___28G'2(7`#X3%
M_O__Z?O^__\/'P"+A"2H````)0#P```]`$````^%=____T2+O"2L````Z$3G
M__]!.<</A6'___^+A"2H````)?\!```]P`$```^%2O___TR)Y^@LY?__2(GN
M2(T]BR4``$F)Q#'`Z.CJ__](A<`/A$\"``!)BSY(B<;H!//__TF)QTB%P`^$
M.`(``$R)_^B0Y?__2(G"@_@#?D!(F$B--88E``!(B50D"$F-?`?\Z)#F__^%
MP'4D2(M4)`B#^@0/A.8"``"-0OM(F$&`/`<O#X36`@``9@\?1```2(GN2(TM
MC20``#'`2(GOZ&3J__](A<`/A-L!```/M@"$P`^$T`$``#PP#X3(`0``2(GO
M2(TURB0``#'`Z-?N__](C2U`)0``3(TU)R4``.BTY/__54C'PO____]-B>A0
M3(T-\2,``+X!````3(GG2(T-\B0``#'`Z&OF__]86NM'#Q^``````.B;Y?__
M@S@1=4CH<>3__X/#`4B#[`A-B>A53(T-KR,``$R)\;X!````4TC'PO____],
MB>=0,<#H).;__TB#Q""^P`$``$R)Y^B#YO__@_C_=*Y,B>_H5N3__TR)YDB-
M/50C```QP.@E[O__3(GGZ!WZ___IX?W__P\?A```````13'_Z1C]__\/'X0`
M`````$B-7"1`ZPUF#Q^$``````!(@\,(2(L[2(7_#X2(````,<!(B>[H-NG_
M_TB%P'3A@#@`=-Q(B<?HY.3__TF)Q$B%P'3,Z=;[__])BPY(BSW=@@``38GH
M,<!(C15!)```O@$```#HU^+__^E8_?__9I!(B<?HB/G__TB+A"1H`0``9$@K
M!"4H````#X5D`0``2('$>`$``$B)WUM=05Q!74%>05_I>.3__[\-````3(TE
M2B,``.C7XO__0;A3````28G'2(G#Z7?[__]F#Q]$``!-BS[IP/W__P\?A```
M````,?9,B?\QP.BTX___08G&A<`/A"'^__^)Q^@RZ___28G'2(7`#X@._O__
M,=)(C7#V1(GWZ)CD__](C;0D*@$``+H&````1(GWZ$/B__^!O"0J`0```$-!
M0P^%VOW__V:!O"0N`0``2$4/A<K]__](C9PD,`$``$F-=\XQTD2)]^A,Y/__
MNB@```!(B=Y$B??H_.'__[X!````38GH3(GG2(T%ZB(``,:$)%@!````2(T-
MK"(``$C'PO____]03(T-G"$``#'`4^@DY/__65[I#_[__P\?1```38MV"$V%
M]@^$(_W__TR)]^ACXO__2(/X`P^&$?W__TF-?`;\2(TU62(``.AHX___A<!-
M#T3^Z?7\___H2./__P\?A```````051(C3U:(0``55-(@^P02(L=FH```&1(
MBP0E*````$B)1"0(,<!,C60D!$R)YF1(BRL/MH6P````B(6Q````,<#H&N?_
M_TB%P'0)@#@Q#X1D`0``,<#HM?+__V1(BRM(B>^Y`P```+H!````2(TU_"$`
M`.@XX?__2(G%2(7`="A(BT`09$B+.TB-%>(A``!(BS#H2>'__TB+11!(BS#V
M1@Y`#X5(`0``9$B+.[D#````N@$```!(C36Y(0``Z.[@__](B<5(A<!T+4R)
MYDB-/5T@```QP.B%YO__2(G"2(7`#X3I````2(M%$&1(BSM(BS#HZ>#__V1(
MBSNZ`0```$B--7$A``#H!.#__V1(BSM(C15V(0``2(G&Z,'@__]D2(L#3(GF
M2(T]^Q\``,:`L0`````QP.@EYO__2(D%#H```$B)PTB%P'0^OL`!``!(B=_H
MZ>+__XU0`8/Z`78)@_@1#X66````2(M$)`AD2"L$)2@````/A9\```!(@\00
M6UU!7,,/'P!(BSW)?P``Z'SW__](B06U?P``2(G#2(7`=:=(C3V.(0``,<#H
MW^'__P\?@`````"`>`$`#X2=_O__Z8W^__]F#Q^$``````!(BP6!?P``2(LP
M2(M%$$B+..A*Z?__Z0S___\/'T0``&1(BSOH-^'__^FJ_O__B<%(BP51?P``
M2(G:2(T]3R$``$B+,#'`Z'7A___H(.'__U5(B?U32(/L&&1(BP0E*````$B)
M1"0(,<#HDN___[XO````2(G'2(G#Z$+@__](A<!(C5`!2`]%VDB)W^B_X/__
M2(UT)`1(C3T2'P``2(G#,<#HZ>3__TB%P'0D#[80A-(/E,"`^C`/E,((T'42
M2(7M=`V`?0``=2</'X``````2(M$)`AD2"L$)2@```!U1DB#Q!A;7<-F#Q^$
M``````"Z!````$B--68?``!(B=_HK-[__X7`=<A(BT0D"&1(*P0E*````'4.
M2(/$&$B)[UM=Z<KE___H1>#__P\?1```05=(B?Y,C4<X059!54%455-(@>R8
M`@``9$B+!"4H````2(F$)(@"```QP$B)XDR-C"2`````2(G7#Q^``````$&+
M`$V+$$B#QQ!)@\`(#\B)P$R)T4B)1_!,B=!(P>D@2,'H*$G!ZC@E`/\``$P)
MT$F)RDC!X0A)P>(8@>$``/\`18G23`G02`G(2(E'^$PYSW6M9@]O1"009@]O
M7"0@2(U$)&A(@<)H`@``9@]O5"0P9@]O+7==```/'X``````\P]O"&8/;^)F
M#V]0V$B#P!!F#^]`B&8/[\IF#^_!9@]OR&8/<]`?9@]S\0%F#^O!9@_;Q0\I
M0`AF#V_#9@]OW$@YT'6[3(L.3(M>$$B+?B!(BUX83(G(3(G*2(MN"$B+3"0(
M2,'J&TC!X`5("=`#!"1(C8P+F7F"6HV4.)EY@EI,B=A(,=A((>A(,=B-/`)(
MB>I(B>A(P>@"2,'B'DF)^D@)PDR)V$G!ZAM!B=!,,<!,(<A,,=A(`<A(B?E(
MP>$%3`G13(M4)!!$C20(3(G(3(G)2,'I`DC!X!Y/C903F7F"6DV)Y4@)R$G!
M[1M(,<*)P4@A^DPQPDP!TDV)XDG!X@5-">I,BVPD&$$!TDB)^DC![P)(P>(>
M18G23XV$*)EY@EI("?I-B=5(,=")UTPAX$G![1M(,<A,`<!-B=!)P>`%30GH
M3(ML)"!!`<!,B>!)P>P"2,'@'D6)P$J-C"F9>8):3`G@38G%2#'"2<'M&T&)
MQ$PATD@Q^D@!RDR)P4C!X05,">E,BVPD*`'13(G22<'J`DC!XAZ)R4J-O"^9
M>8):3`G228G-2#'02<'M&T&)TDPAP$PQX$@!^$B)STC!YP5,">],BVPD,`''
M3(G`2<'H`DC!X!Z)_T^-I"R9>8):3`G`28G]2#'"2<'M&T&)P$@ARDPQTDP!
MXDF)_$G!Y`5-">Q,BVPD.$$!U$B)RDC!Z0)(P>(>18GD3XV4*IEY@EI("<I-
MB>5(,=!)P>T;B=%((?A,,<!,`=!-B>))P>(%30GJ3(ML)$!!`<)(B?A(P>\"
M2,'@'D6)TD^-A"B9>8):2`GX38G52#'"2<'M&XG'3"'B2#'*3`'"38G02<'@
M!4T)Z$R+;"1(00'03(GB2<'L`DC!XAY%B<!*C8PIF7F"6DP)XDV)Q4@QT$G!
M[1M!B=1,(=!(,?A(`<A,B<%(P>$%3`GI3(ML)%`!P4R)T$G!Z@)(P>`>B<E*
MC;POF7F"6DP)T$F)S4@QPDG![1M!B<),(<),,>)(`?I(B<](P><%3`GO3(ML
M)%@!UTR)PDG!Z`)(P>(>B?]/C:0LF7F"6DP)PDF)_4@QT$G![1M!B=!((<A,
M,=!,`>!)B?Q)P>0%30GL3(ML)&!!`<1(B<A(P>`>2,'I`D6)Y$^-E"J9>8):
M2`G(38GE2#'"2<'M&XG!2"'Z3#'"3`'238GB2<'B!4T)ZDR+;"1H00'22(GZ
M2,'O`DC!XAY%B=)/C80HF7F"6D@)^DV)U4@QT$G![1N)UTPAX$@QR$P!P$V)
MT$G!X`5-">A,BVPD<$$!P$R)X$G![`)(P>`>18G`2HV,*9EY@EI,">!-B<5(
M,<))P>T;08G$3"'22#'Z2`'*3(G!2,'A!4P)Z4R+;"1X`=%,B=)(P>(>2<'J
M`HG)2HV\+YEY@EI,"=))B<U(,=!)P>T;08G23"'`3#'@2`'X2(G/2,'G!4P)
M[TR+K"2``````<=,B<!)P>@"2,'@'HG_3XVD+)EY@EI,"<!)B?U(,<))P>T;
M08G`2"'*3#'23`'B28G\2<'D!4T)[$:-+")(B<I(P>D"3(ND)(@```!(P>(>
M2`G*3XV4(IEY@EI-B>Q(,=!)P>P;B=%((?A,,<!,`=!-B>I)P>(%30GB3(ND
M))````!!`<)(B?A(P>`>2,'O`D6)TD^-A""9>8):2`GX38G42#'"2<'L&XG'
M3"'J2#'*3`'"38G02<'@!4T)X$6)P$P!PDV)Z$G![0))P>`>08G430GH3(NL
M))@```!,,<!,(=!*C8PIF7F"6DV)Y4@Q^$G![1M(`<A,B>%(P>$%3`GIB<E(
M`<A,B=%)P>H"2,'A'D&)Q4P)T4V)PD6)P$DQRD0QTDR+E"2@````2HV\%Z'K
MV6Y-B>I(`==,B>I)P>H;2,'B!4P)THG22`'73(GB2,'B'DG![`)!B?I,`X0D
MJ````$P)XDF)S(G)2`.,)+````!),=1$,>!-C:0`H>O9;DR)T$V)T$G!Z!M(
MP>`%3`G`B<!)`<1,B>A)P>T"2,'@'D6)X$P)Z$F)U8G22`.4)+@```!),<5$
M,>],C:PYH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,B=%)P>H"2,'A'D2)
M[TP)T4F)PHG`23'*13'B3HVD$J'KV6Y(B?I)B?I)P>H;2,'B!4P)THG220'4
M3(G"2<'H`DC!XAY%B>),"<))B<A(`X0DP````(G)23'02`.,),@```!%,>A.
MC:P`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<5(B?A(P>\"2,'@'D6)Z$@)
M^$B)UXG22`.4)-````!(,<=$,>=,C:0YH>O9;DR)P4R)QTC![QM(P>$%2`GY
MB<E)`<Q,B=%)P>H"2,'A'D2)YTP)T4F)PHG`2`.$)-@```!),<I%,>I.C:P2
MH>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=5,B<))P>@"2,'B'D6)ZDP)PDF)
MR(G)23'02`.,).````!%,>!.C:0`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)
M`<1(B?A(P>\"2,'@'D6)X$@)^$B)UXG22`.4).@```!(,<=$,>],C:PYH>O9
M;DR)P4R)QTC![QM(P>$%2`GYB<E)`<U,B=%)P>H"2,'A'D2)[TP)T4F)PHG`
M2`.$)/````!),<I%,>).C:02H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=1,
MB<))P>@"2,'B'D6)XDP)PDF)R(G)23'013'H3HVL`*'KV6Y,B=!-B=!(P>`%
M2<'H&T@#C"3X````3`G`B<!)`<5(B?A(P>\"2,'@'D6)Z$@)^$B)UXG22`.4
M)``!``!(,<=$,>=,C:0YH>O9;DR)P4R)QTC![QM(P>$%2`GYB<E)`<Q,B=%)
MP>H"2,'A'D2)YTP)T4F)PHG`2`.$)`@!``!),<I%,>I.C:P2H>O9;DB)^DF)
M^DG!ZAM(P>(%3`G2B=))`=5,B<))P>@"2,'B'D6)ZDP)PDF)R(G)23'013'@
M3HVD`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P$@#C"00`0``B<!)`<1(B?A(P>\"
M2,'@'D6)X$@)^$B)UXG22`.4)!@!``!(,<=$,>],C:PYH>O9;DR)P4R)QTC!
M[QM(P>$%2`GYB<E)`<U,B=%)P>H"2,'A'D2)[TP)T4F)PHG`2`.$)"`!``!)
M,<I%,>).C:02H>O9;DB)^DF)^DG!ZAM(P>(%3`G2B=))`=1,B<))P>@"2,'B
M'D6)XDP)PDF)R(G)23'013'H3HVL`*'KV6Y,B=!-B=!)P>@;2,'@!4P)P(G`
M20'%2(GX2,'@'DC![P)%B>A(`XPD*`$``$@)^$B)UXG22`.4)#`!``!(,<=$
M,>=-B<1(C8PYH>O9;DR)QTG![!M(P><%3`GG38G42<'J`DG!Y!Z)_TT)U$F)
MPD@!^8G`33'BB<](`X0D.`$``$4QZDF)_4Z-E!*AZ]EN2(GZ2<'M&TC!X@5,
M">I!`=),B<))P>@"2,'B'D6)TDP)PDV)X$6)Y$DQT$F)UD&)U40QP4V)T$B-
MC`BAZ]EN3(G02<'H&TC!X`5,"<!$C00!2(GY2,'O`KC<O!N/2,'A'D@)^4D)
MSHG/2"'Z32'620G62(N4)$`!``!(`<),`>)-B<1,`?)-B<9)P>0%2<'N&TT)
M]$$!U$R)TDG!Z@)(P>(>18GD3`G22`G128G608G222'^3"'!3`GQ3(NT)$@!
M``!)`<9-`?5-B>9,`>E-B>5)P>X;2<'E!4T)]4F)UD$!S4R)P4G!Z`)(P>$>
M18GM3`G!08G(20G.32'F3"'"3`GR3(NT)%`!``!)`<9,`?=-B>Y(`?I,B>])
MP>X;2,'G!4P)]P'73(GB2<'L`DC!XAZ)_TP)XD@)T4F)UD&)U$TAQDPAZ4P)
M\4R+M"18`0``20'&30'R28G^3`'128GZ2<'N&TG!X@5-"?))B=9!`<I,B>E)
MP>T"2,'A'D6)TDP)Z4&)S4D)SDDA_DPAZDP)\DR+M"1@`0``20'&30'P38G6
M3`'"38G02<'@!4G![AM-"?!!`=!(B?I(P>\"2,'B'D6)P$@)^D@)T4F)UHG7
M32'N3"'13`GQ3(NT)&@!``!)`<9-`?1-B<9,`>%-B<1)P>X;2<'D!4T)]$F)
MUD$!S$R)T4G!Z@)(P>$>18GD3`G108G*20G.32'&3"'23`GR3(NT)'`!``!)
M`<9-`?5-B>9,`>I-B>5)P>X;2<'E!4T)]4$!U4R)PDC!XAY)P>@"18GM3`G"
M2`G128G608G032'63"'A3`GQ3(NT)'@!``!)`<9,`?=-B>Y(`?E,B>])P>X;
M2,'G!4P)]TF)U@'/3(GA2<'L`DC!X1Z)_TP)X4&)S$D)SDTA[DPAXDP)\DR+
MM"2``0``20'&30'R28G^3`'228GZ2<'N&TG!X@5-"?)!`=),B>I)P>T"2,'B
M'D6)TDP)ZD@)T4F)UD&)U4@A^4TAYDP)\4R+M"2(`0``20'&30'P38G63`'!
M38G02<'N&TG!X`5-"?!)B=9!`<A(B?E(P>\"2,'A'D6)P$@)^8G/20G.32'6
M2"'Z3`GR3(NT))`!``!)`<9-`?1-B<9,`>)-B<1)P>X;2<'D!4T)]$$!U$R)
MTDG!Z@)(P>(>18GD3`G22`G128G608G222'^3"'!3`GQ3(NT))@!``!)`<9-
M`?5-B>9,`>E-B>5)P>X;2<'E!4T)]4F)UD$!S4R)P4G!Z`)(P>$>18GM3`G!
M08G(20G.32'F3"'"3`GR3(NT)*`!``!)`<9,`?=-B>Y(`?I,B>])P>X;2,'G
M!4P)]P'73(GB2<'L`DC!XAZ)_TP)XD@)T4F)UD&)U$TAQDPAZ4P)\4R+M"2H
M`0``20'&30'R28G^3`'128GZ2<'N&TG!X@5-"?))B=9!`<I,B>E)P>T"2,'A
M'D6)TDP)Z4&)S4D)SDDA_DPAZDP)\DR+M"2P`0``20'&30'P38G63`'"38G0
M2<'N&TG!X`5-"?!!`=!(B?I(P>\"2,'B'D6)P$@)^D@)T4F)UHG732'N3"'1
M3`GQ3(NT)+@!``!)`<9-`?1-B<9,`>%-B<1)P>X;2<'D!4T)]$F)UD$!S$R)
MT4G!Z@)(P>$>18GD3`G120G.08G*32'&3"'23`GR3(NT),`!``!)`<9-`?5-
MB>9,`>I-B>5)P>X;2<'E!4T)]4$!U4R)PDG!Z`)(P>(>18GM3`G"2`G128G0
M08G732'03"'A3`G!3(N$),@!``!)`<!,`<=-B>A(`?E,B>])P>@;2,'G!4P)
MQT2-!#E,B>=)P>P"2(G12,'G'DP)YT&)_$@)^4PAZ4PAXD@)RDB+C"30`0``
M2`'!3`'138G"2`.$)-@!``!(`<I,B<%)P>H;2,'A!4P)T8G)2`'*3(GI2<'M
M`DC!X1Y!B=),">E("<])B<U!B<Y,(<=-(>5)"?U*C3PX3(G03(N\)/@!``!,
M`>]-B=5(P>`%2<'M&TP)Z(G`2`''3(G`2<'H`DC!X!Y!B?U)"<"XUL%BRDPQ
MP3'12(N4).`!``!(`<),`>)-B>Q(`<I,B>E)P>P;2,'A!4P)X4V)U(G)2<'D
M'D@!RDG!Z@))`<=-">)-B<2)T46)P$TQU$0QYTR+I"3H`0``20'$30'T28G.
M3`'G28G,2<'N&TG!Y`5-"?1-B>Y)P>T"2<'F'D6)Y$T)]4R+M"3P`0``3`'G
M08G\20'&30'P38G633'N1#'R38GF20'03(GB2<'N&TC!X@5,"?*)TDD!T$B)
MRDC!Z0)(P>(>18G&2`G*1(G138GJ23'23`'Y3(N\)``"``!$,==-B?)(`<],
MB?%(P>$%2<'J&TD!QTP)T8G)2`'/3(GA2<'L`DC!X1Y!B?I)"<Q$B>E)B=6)
MTDTQY4P!^4R+O"00`@``13'H38G520'(3(G12<'M&TD!QTC!X05,">F)R4D!
MR$R)\4G![@)(P>$>18G%3`GQ3(NT)`@"``!)`<9,`?)-B>9),<Y$,?=-B>Y(
M`==,B>I)P>X;2,'B!4P)\HG22`'73(G22<'J`DC!XAY!B?Y)"=)$B>))B<R)
MR4P!^DTQU$R+O"0@`@``13'@38GT20'03(GR2<'L&TD!QTC!X@5,">*)TDD!
MT$R)ZDG![0)(P>(>18G$3`GJ3(NL)!@"``!)`<5,`>E-B=5),=5$,>]-B>5(
M`<],B>%)P>T;2,'A!4P)Z8G)2`'/3(GQ2<'N`DC!X1Y!B?U)"<Y$B=%)B=*)
MTDTQ\DP!^4R+O"0P`@``13'038GJ20'(3(GI2<'J&TC!X05,"=&)R4D!R$R)
MX4C!X1Y)P>P"18G"20''3`GA3(ND)"@"``!)`<1,`>)-B?1),<Q$,>=-B=1(
M`==,B=))P>P;2,'B!4P)XHG22`'73(GJ2<'M`DC!XAY!B?Q)"=5$B?))B<Z)
MR4TQ[DP!^DR+O"1``@``13'P38GF20'03(GB2<'N&TC!X@5,"?*)TDD!T$R)
MTDG!Z@)(P>(>18G&3`G23(N4)#@"``!)`<),`=%-B>I),=)$,==-B?)(`<],
MB?%(P>$%2<'J&TD!QTP)T8G)2`'/3(GA2<'L`DC!X1Y!B?I)"<Q$B>E)B=6)
MTDTQY4P!^4R+O"1@`@``13'H38G520'(3(G12<'M&TC!X05,">F)R4D!R$R)
M\4G![@)(P>$>18G%3`GQ3(NT)$@"``!)`<9,`?)-B>9%B>1),<Y$,?=-B>Y(
M`==,B>I)P>X;2,'B!4P)\HG22`'73(G22<'J`DC!XAY!B?Y)"=)(BY0D4`(`
M`$@!PDD!U$B)RHG)3#'220''1#'"38GP20'43(GR2<'H&TC!X@5,"<*)TDD!
MU$R)ZDG![0)(P>(>18G@3`GJ3(NL)%@"``!)`<5,`>E-B=5),=5$,>]-B<5(
M`<],B<%)P>T;2,'A!4P)Z8G)2`'/3(GQ2<'N`DC!X1Y!B?U)"<Y$B=%)B=*)
MTDTQ\DP!^4R+O"1P`@``13'B38GL3`'138GJ2<'L&TG!X@5-">)-B<1%B=))
MP>0>3`'12<'H`DD!QTT)X$R+I"1H`@``08G*20'$2`.$)'@"``!,`>)-B?1,
M`<A-,<1$,>=-B=1(`==,B=))P>P;2,'B!4P)XDV)[$G![0))P>0>B=)-">5%
MB?1-B<9(`==-,>Z)^DT!_$6)P$0Q\4F)UDP!P$V)Z$P!X4F)U$G![AM)P>0%
M30GT1`'A38G42<'J`DG!Y!Z)R4T)XDTQT$0QQTF)R$@!^$B)STC!YP5)P>@;
M`>E!`=I,"<=$`VX@2(E."`'X3(E6&$B)!DB)T$C!Z@)(P>`>3(EN($@)T$0!
MV$B)1A!(BX0DB`(``&1(*P0E*````'422('$F`(``%M=05Q!74%>05_#Z-;)
M__]F#Q]$``!(@^P(OX````#H$LC__V8/;P6Z1P``2,=`,``````/$0!F#V\%
MMT<``,=`>``````/$4`09@]O!;1'```/$4`@2(/$",-F9BX/'X0``````$%7
M2&/"059)B<9!54%428G\54B-;SA32(GS2(/L"$B+=RA(BU<PC0S&2#GQ2(E/
M*$B#T@!(P>@=2`'02(E',$AC1WB%P`^%[0```$&#_C\/CBL!``!!@^Y`18GW
M0<'O!D6-;P%)P>4&20'=#Q]$``#S#V\#3(GG2(/#0`\110#S#V]+T`\131#S
M#V]3X`\152#S#V];\`\173#HH>C__TPYZW7,0<'G!D4I_DECQDB#^`AR7$F+
M50!(C4T(2(/A^$F)5"0X28M4!?A(B50%^$@IS4@!Z$DI[4B#X/A(@_@(<AA(
M@^#X,=))BW05`$B)-!%(@\((2#G"<NY%B70D>$B#Q`A;74%<05U!7D%?PV:0
MJ`1U=$B%P'3A00^V50!!B%0D.*@"=--!#[=4!?YFB50%_NO&#Q]``$&_0```
M`$B-?`4`2(G>02G'13GW10]/_DUC[TR)ZN@%R?__08M$)'A$`?A!B40D>(/X
M0'623(GG12G^3`'KZ,7G___IR_[__TF)W>DC____08M5`$&)5"0X08M4!?R)
M5`7\Z5O___^0059,C78X055!5%5(B?U33(MN*$B)\TR+9C!,B>A(P>@#@^`_
MC4@!2)C&1`8X@$ACP4P!\(/Y.`^.@P$``+Y`````*<YT#S'2B=&#P@'&!`@`
M.?)R\TB)W^A#Y___9@_OP`\10SA)QT8P`````$$/$48000\11B!,B>)!#[;%
M3(GO3(GN2,'J&$C!X`A,B>%(P>\028G03(GJ2,'N&`^VUD`/MO]`#[;V2,'I
M$$@)T$R)X@^VR4C!X`A("?@/MOY!#[;02,'@"$@)\$$/MO1(P>`(2`GP2,'@
M"$@)^$B)WTC!X`A("<A(P>`(2`G02(E#<.BJYO__2(L#2(G?2,'H&(A%`$B+
M`TC!Z!"(10%(BP.(90)(BP.(10-(BT,(2,'H&(A%!$B+0PA(P>@0B$4%2(M#
M"(AE!DB+0PB(10=(BT,02,'H&(A%"$B+0Q!(P>@0B$4)2(M#$(AE"DB+0Q"(
M10M(BT,82,'H&(A%#$B+0QA(P>@0B$4-2(M#&(AE#DB+0QB(10](BT,@2,'H
M&(A%$$B+0R!(P>@0B$412(M#((AE$DB+0R"(11-;74%<05U!7ND*Q?__9BX/
M'X0``````+HX````,?\IRH/Z"')"B=%(QP``````2,=$"/@`````2(U("$B#
MX?A(*<@!PH/B^(/Z"`^"?O[__X/B^#'`B<:#P`A(B3PQ.=!R\^EG_O__]L($
M=2.%T@^$6O[__\8``/;"`@^$3O[__S')9HE,$/[I0O[__P\?`,<``````,=$
M$/P`````Z2S^__\/'T0``$B+#2%C``#II,/__TB#[`A(@\0(PP``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"5S+R5S`"]P<F]C+W-E;&8O97AE`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@`Q`$Q$7TQ)0E)!4EE?4$%42`!365-414T`
M+W1M<`!414U01$E2`%1-4`!54T52`%5315).04U%`"4P,G@`)7,E<R5S)7,`
M<&%R+0!P87)L`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E
M<R5S=&5M<"TE=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].
M`#$N,#4X`"UE`"TM```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```````````E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*``````````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D1DE,15]O
M9F9S971?<VEZ92P@)&-A8VAE7VYA;65?<VEZ92D["D)%1TE.('L*)%!!4E]-
M04=)0R`](")<;E!!4BYP;5QN(CL*)$9)3$5?;V9F<V5T7W-I>F4@/2`T.R`@
M(",@<&%C:R@B3B(I"B1C86-H95]N86UE7W-I>F4@/2`T,#L*)%!+6DE07TU!
M1TE#(#T@(E!+7#`P,UPP,#0B.PI]"G-U8B!F:6YD7W!A<E]M86=I8PI["FUY
M("@D9F@I(#T@0%\["FUY("1C:'5N:U]S:7IE(#T@-C0@*B`Q,#(T.PIM>2`D
M8G5F.PIM>2`D<VEZ92`]("US("1F:#L*;7D@)'!O<R`]("@D<VEZ92TQ*2`M
M("@D<VEZ92TQ*2`E("1C:'5N:U]S:7IE.R`@("`@(",@3D]413H@)'!O<R!I
M<R!A(&UU;'1I<&QE(&]F("1C:'5N:U]S:7IE"G=H:6QE("@D<&]S(#X](#`I
M('L*<V5E:R`D9F@L("1P;W,L(#`["G)E860@)&9H+"`D8G5F+"`D8VAU;FM?
M<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*:68@*"AM>2`D:2`](')I;F1E
M>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@>PIR971U<FX@)'!O<R`K("1I
M.PI]"B1P;W,@+3T@)&-H=6YK7W-I>F4["GT*<F5T=7)N("TQ.PI]"FUY("@D
M<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D[
M"D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P
M96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R
M7W1E;7`I.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B
M72D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I
M<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF
M("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP
M(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)
M4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8
M(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T
M;7`M/F9I;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@
M6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA
M("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E
M>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T
M;7`["F-H;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA
M;64@/B]D978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;
M4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P
M.B`D9FEL96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ
M0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L
M('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A)$5.5GM005)?1$5"
M54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7
M:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_
M.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*
M7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA;64@/2`B)'!R;V=N
M86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;7"1%3E9[4$%27U1%
M35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T87)T7W!O<RP@)'-T
M87)T7V]F7T9)3$5?<V5C=&EO;BD["DU!1TE#.B!["FQO8V%L("1324=[7U]7
M05).7U]](#T@<W5B('M].PIU;FQE<W,@*&]P96X@7T9(+"`G/#IR87<G+"`D
M<')O9VYA;64I('L*;W5T<RAQ<5M#86XG="!R96%D(&9R;VT@9FEL92`B)'!R
M;V=N86UE(ETI.R`@(R!D;VXG="!U<V4@)"$@:&5R92!A<R!I="!R97%U:7)E
M<R!%<G)N;RYP;0IL87-T($U!1TE#.PI]"FUY("1M86=I8U]P;W,@/2!F:6YD
M7W!A<E]M86=I8R@J7T9(*3L*:68@*"1M86=I8U]P;W,@/"`P*2!["F]U=',H
M<7%;0V%N)W0@9FEN9"!M86=I8R!S=')I;F<@(B1005)?34%'24,B(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0SL*?0IO=71S*")&;W5N9"!0
M05(@;6%G:6,@870@<&]S:71I;VX@)&UA9VEC7W!O<R(I.PIS965K(%]&2"P@
M)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE("T@;&5N9W1H*")<,$-!
M0TA%(BDL(#`["G)E860@7T9(+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*
M:68@*"1B=68@;F4@(EPP0T%#2$4B("8F("1B=68@;F4@(EPP0TQ%04XB*2![
M"F]U=',H(DYO(&-A8VAE(&UA<FME<B!F;W5N9"(I.PIL87-T($U!1TE#.PI]
M"F]U=',H<7%;0V%C:&4@;6%R:V5R("(D8G5F(B!F;W5N9%TI.PIS965K(%]&
M2"P@)&UA9VEC7W!O<R`M("1&24Q%7V]F9G-E=%]S:7IE+"`P.PIR96%D(%]&
M2"P@)&)U9BP@)$9)3$5?;V9F<V5T7W-I>F4["FUY("1O9F9S970@/2!U;G!A
M8VLH(DXB+"`D8G5F*3L*;W5T<R@B3V9F<V5T(&9R;VT@<W1A<G0@;V8@1DE,
M17,@:7,@)&]F9G-E="(I.PIS965K(%]&2"P@)&UA9VEC7W!O<R`M("1&24Q%
M7V]F9G-E=%]S:7IE("T@)&]F9G-E="P@,#L*)'-T87)T7V]F7T9)3$5?<V5C
M=&EO;B`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@
M)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE
M(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?
M1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F
M*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,
M12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@
M<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N
M86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D[
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_
M.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B
M)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H
M97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A
M8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS92!["B1-;V1U;&5#
M86-H97LD9G5L;&YA;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L
M"FYA;64@/3X@)&9U;&QN86UE+`I].PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M
M97TK*SL*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U
M8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D
M;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D:6YF;R`]("1-;V1U;&5#86-H97LD
M;6]D=6QE?3L*<F5T=7)N('5N;&5S<R`D:6YF;SL*9&5L971E("1R97%U:7)E
M7VQI<W1[)&UO9'5L97T["B1)3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF
M;R\D;6]D=6QE(CL*:68@*"1%3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F
M24\Z.D9I;&4Z.FYE=RDI('L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F
M:6QE(&]R(&1I92`B0V%N)W0@8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M
M/F)I;FUO9&4H*3L*)&9H+3YP<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E
M96LH,"P@,"D["G)E='5R;B`D9F@["GT*96QS92!["FUY("1F:6QE;F%M92`]
M(%]S879E7V%S*"(D:6YF;RT^>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PHD
M:6YF;RT^>V9I;&5](#T@)&9I;&5N86UE.PIO<&5N(&UY("1F:"P@)SPZ<F%W
M)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B
M.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL
M92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP
M72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@
M+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E
M<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S
M("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*:68@*"1B=68@;F4@)%!+
M6DE07TU!1TE#*2!["F]U=',H<7%;3F\@>FEP(&9O=6YD(&%F=&5R($9)3$4@
M<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,@.PI]
M"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@("`@("`@("`@("`@("`@
M(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,["FUY("@D;W5T+"`D8G5N
M9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L971E("1%3E9[4$%27T%0
M4%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA>2!B92!A('-E8W5R:71Y
M('!R;V)L96TI"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM
M<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*
M<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL
M7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6
M(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%
M3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N
M;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`
M05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI
M+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE
M;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE
M;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@
M)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@
M>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I
M970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^
M/B(L("0R(&]R(&1I92!Q<5M#86XG="!O<&5N(&QO9R!F:6QE("(D,B(Z("0A
M73L*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*
M<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*
M9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@
M4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'
M5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*
M?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@
M>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR
M97%U:7)E($1I9V5S=#HZ4TA!.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD[
M"FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D9F@L("<\
M.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(&9I;F0@<&%R(&9I;&4@(B1P
M87(B.B`D(5T["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H
M+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@<7%;
M17)R;W(@<F5A9&EN9R!Z:7`@87)C:&EV92`B)'!A<B)=.PI]"FUY("5M971A
M7W!A<B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N
M=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,[
M"B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@
M*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P
M:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL
M92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I
M92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q
M("102UI)4%]-04=)0SL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?4D174B@I('P@24\Z.D9I;&4Z.D]?5%)5
M3D,H*2P*,#<W-RP**2!O<B!D:64@<7%;0V%N)W0@8W)E871E(&9I;&4@(B1O
M=70B.B`D(5T["B1F:"T^8FEN;6]D92@I.PIS965K(%]&2"P@,"P@,#L*;7D@
M)&QO861E<CL*:68@*&1E9FEN960@)'-T87)T7V]F7T9)3$5?<V5C=&EO;BD@
M>PIR96%D(%]&2"P@)&QO861E<BP@)'-T87)T7V]F7T9)3$5?<V5C=&EO;CL*
M?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]
M"FEF("@A)$5.5GM005)?5D520D%424U](&%N9"`D;&]A9&5R(#U^("]>*#\Z
M(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*
M4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]
M"B1F:"T^<')I;G0H)&QO861E<BD*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@
M;&]A9&5R('1O("(D;W5T(CH@)"%=.PII9B`H)&)U;F1L92D@>PIR97%U:7)E
M(%!!4CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*
M:6YI=%]I;F,H*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!G<F5P
M('L@(2]"4T1004XO('T*9W)E<"!["B@D8G5N9&QE(&YE("=S:71E)RD@;W(*
M*"1?(&YE("1#;VYF:6<Z.D-O;F9I9WMA<F-H;&EB97AP?2!A;F0*)%\@;F4@
M)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]*3L*?2!`24Y#.PIS?"\K?"]\
M9RP@<WPO)'Q\(&9O<F5A8V@@0&EN8SL*;7D@)69I;&5S.PHD9FEL97-[)%]]
M*RL@9F]R($!$>6YA3&]A9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S
M("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1]
M.R`@("`@("`@(",@6%A8(&QI8E]E>'0@=G,@9&QE>'0@/PIM>2`E=W)I='1E
M;CL*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D
M9FEL92P@)&YA;64I.PII9B`H9&5F:6YE9"AM>2`D9F,@/2`D4$%2.CI(96%V
M>3HZ1G5L;$-A8VAE>R1K97E]*2D@>PHH)&9I;&4L("1N86UE*2`]("@D:V5Y
M+"`D9F,I.PI]"F5L<V4@>PIF;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@
M*"1K97D@/7X@;7Q>7%$D9&ER7$4O*"XJ*21\:2D@>PHH)&9I;&4L("1N86UE
M*2`]("@D:V5Y+"`D,2D["FQA<W0["GT*:68@*"1K97D@/7X@;7Q>+VQO861E
M<B];7B]=*R\H+BHI)'PI('L*:68@*&UY("1R968@/2`D36]D=6QE0V%C:&5[
M)#%]*2!["B@D9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0II
M9B`H+68@(B1D:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q
M(BP@)#$I.PIL87-T.PI]"GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@)&YA
M;64["FYE>'0@:68@)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D
M9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O:3L*;W5T<RAS
M<')I;G1F*'%Q6U!A8VMI;F<@1DE,12`B)7,B+BXN72P@<F5F("1F:6QE(#\@
M)&9I;&4M/GMN86UE?2`Z("1F:6QE*2D["FUY("1C;VYT96YT.PII9B`H<F5F
M*"1F:6QE*2D@>PHD8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*
M;&]C86P@)"\@/2!U;F1E9CL*;W!E;B!M>2`D=&@L("<\.G)A=R<L("1F:6QE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL92(Z("0A73L*)&-O;G1E;G0@
M/2`\)'1H/CL*8VQO<V4@)'1H.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/F%P
M<&QY*%PD8V]N=&5N="P@(CQE;6)E9&1E9#XO)&YA;64B*0II9B`A)$5.5GM0
M05)?5D520D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD[
M"E!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT
M96YT+"`D9FEL92P@)&YA;64I.PI]"B1F:"T^<')I;G0H(D9)3$4B+`IP86-K
M*"=.)RP@;&5N9W1H*"1N86UE*2`K(#DI+`IS<')I;G1F*"(E,#AX+R5S(BP@
M07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H)&-O;G1E;G0I+"`D;F%M92DL
M"G!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2P*)&-O;G1E;G0I"F]R(&1I
M92!Q<5M%<G)O<B!W<FET:6YG(&5M8F5D9&5D($9)3$4@=&\@(B1O=70B.B`D
M(5T["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D["GT*?0II9B`H)'II
M<"D@>PHD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TL*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@>FEP('!A<G0@
M;V8@(B1O=70B73L*?0II9B`H)&UE=&%?<&%R>V-L96%N?2D@>PHD9F@M/G!R
M:6YT*")<,$-,14%.(BD["GT*96QS92!["FEF("@A9&5F:6YE9"`D8V%C:&5?
M;F%M92D@>PIM>2`D8W1X(#T@1&EG97-T.CI32$$M/FYE=R@Q*3L*<V5E:R`D
M9F@L(#`L(#`["B1C='@M/F%D9&9I;&4H)&9H*3L*<V5E:R`D9F@L(#`L(#([
M"B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE
M(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`D8V%C:&5?;F%M95]S:7IE.PHD
M8V%C:&5?;F%M92`N/2`B7#`B('@@*"1C86-H95]N86UE7W-I>F4@+2!L96YG
M=&@@)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*"1C86-H95]N86UE+`HB7#!#
M04-(12(I.PI]"FUY("1O9F9S970@/2`D9F@M/G1E;&P@+2!L96YG=&@H)&QO
M861E<BD["B1F:"T^<')I;G0H<&%C:R@G3B<L("1O9F9S970I+`HD4$%27TU!
M1TE#*3L*)&9H+3YC;&]S92!O<B!D:64@<7%;17)R;W(@=W)I=&EN9R!T<F%I
M;&5R(&]F("(D;W5T(CH@)"%=.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]
M"GL*;&%S="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N
M86UE*"D["G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*?0IM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.R`@("`@("`@("`@("`@
M("`@("`@("`@("`@("`@(R!!<F-H:79E.CI::7`@;W!E<F%T97,@;VX@86X@
M24\Z.DAA;F1L90HD9F@M/F9D;W!E;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D
M:64@<7%;9F1O<&5N*"D@9F%I;&5D.B`D(5T["D%R8VAI=F4Z.EII<#HZ<V5T
M0VAU;FM3:7IE*"US(%]&2"D["FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@
M/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@<F5A
M9&EN9R!Z:7`@87)C:&EV92`B)'!R;V=N86UE(ET["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*#8T("H@,3`R-"D["G!U<V@@0%!!4CHZ3&EB0V%C:&4L
M("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PIO=71S
M*")%>'1R86-T:6YG('II<"XN+B(I.PII9B`H9&5F:6YE9"`D14Y6>U!!4E]4
M14U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*9F]R96%C
M:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I9B`D;65M
M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE;6)E<BT^
M9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M>PI>"B\_
M<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\**%M>+UTK
M*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T7VYA;64@
M/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D97AT<F%C
M=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R
M+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3:VEP<&EN9R`B)&UE
M;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B)&1E<W1?
M;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T:6YG("(D;65M8F5R
M7VYA;64B('1O("(D9&5S=%]N86UE(BXN+ETI.PHH)&UE;6)E<BT^97AT<F%C
M=%1O1FEL94YA;65D*"1D97-T7VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?
M3TLH*2D*;W(@9&EE('%Q6T5R<F]R(&5X=')A8W1I;F<@>FEP(&UE;6)E<B!T
M;R`B)&1E<W1?;F%M92)=.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D
M7D\@97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[
M)'!R;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z
M("0P(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R
M8RYP87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL
M95T@<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]
M("0P(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N
M86UE*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N
M86UE+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E
M*"1N86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ
M4&%T:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T
M:"!D:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q
M=6ER92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R
M.PIR97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V
M87)S.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X
M<&]R=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E
M<75I<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#
M;VYF:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*
M<F5Q=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`[
M"G)E<75I<F4@1&EG97-T.CI32$$["G)E<75I<F4@4$%2.PIR97%U:7)E(%!!
M4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$:7-T.PIR97%U:7)E(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT
M96YT.PIR97%U:7)E(&%T=')I8G5T97,["F5V86P@>R!R97%U:7)E($-W9"!]
M.PIE=F%L('L@<F5Q=6ER92!7:6XS,B!].PIE=F%L('L@<F5Q=6ER92!38V%L
M87(Z.E5T:6P@?3L*979A;"![(')E<75I<F4@07)C:&EV93HZ56YZ:7`Z.D)U
M<G-T('T["F5V86P@>R!R97%U:7)E(%1I93HZ2&%S:#HZ3F%M961#87!T=7)E
M('T["F5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER92!097)L24\Z.G-C
M86QA<B!].PIE=F%L('L@<F5Q=6ER92!U=&8X('T["GT*<W5B(%]S971?<&%R
M7W1E;7`@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM0
M05)?5$5-4'T@/7X@+R@N*RDO*2!["B1P87)?=&5M<"`]("0Q.PIR971U<FX[
M"GT*9F]R96%C:"!M>2`D<&%T:"`H"BAM87`@)$5.5GLD7WTL('%W*"!005)?
M5$U01$E2(%1-4$1)4B!414U01$E2(%1%35`@5$U0("DI+`IQ=R@@0SI<7%1%
M35`@+W1M<"`N("D**2!["FYE>'0@=6YL97-S(&1E9FEN960@)'!A=&@@86YD
M("UD("1P871H(&%N9"`M=R`D<&%T:#L*;7D@)'5S97)N86UE.PIM>2`D<'=U
M:60["F5V86P@>R@D<'=U:60I(#T@9V5T<'=U:60H)#XI(&EF(&1E9FEN960@
M)#X[?3L*:68@*"!D969I;F5D*"97:6XS,CHZ3&]G:6Y.86UE*2`I('L*)'5S
M97)N86UE(#T@)E=I;C,R.CI,;V=I;DYA;64["GT*96QS:68@*&1E9FEN960@
M)'!W=6ED*2!["B1U<V5R;F%M92`]("1P=W5I9#L*?0IE;'-E('L*)'5S97)N
M86UE(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-
M)SL*?0IM>2`D<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N
M<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*
M;7D@)&-A8VAE7V1I<CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PHD8V%C:&5?
M9&ER(#T@(G1E;7`M)"0B.PI]"F5L<V4@>PIO<&5N(&UY("1F:"P@(CPZ<F%W
M(BP@)'!R;V=N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B
M.B`D(5T["FEF("@H;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"1F
M:"DI(#X](#`I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,15]O9F9S
M971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I+"`P.PIM>2`D8G5F.PIR96%D
M("1F:"P@)&)U9BP@;&5N9W1H*")<,$-!0TA%(BD["FEF("@D8G5F(&5Q(")<
M,$-!0TA%(BD@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E
M=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BD*+2`D8V%C:&5?;F%M95]S:7IE
M+"`P.PIR96%D("1F:"P@)&)U9BP@)&-A8VAE7VYA;65?<VEZ93L*)&)U9B`]
M?B!S+UPP+R]G.PHD8V%C:&5?9&ER(#T@(F-A8VAE+21B=68B.PI]"GT*8VQO
M<V4@)&9H.PI]"FEF("@A)&-A8VAE7V1I<BD@>PHD8V%C:&5?9&ER(#T@(G1E
M;7`M)"0B.PHD14Y6>U!!4E]#3$5!3GT@/2`Q.PI]"B1S=&UP9&ER("X]("(D
M<WES>U]D96QI;7TD8V%C:&5?9&ER(CL*;6MD:7(@)'-T;7!D:7(L(#`W-34[
M"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FQA<W0["GT*)'!A<E]T96UP
M(#T@)#$@:68@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^
M("\H+BLI+SL*?0IS=6(@7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT
M<RP@)&UO9&4I(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA
M;64B.PIU;FQE<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B
M)&9U;&QN86UE+B0D(CL*;7D@)&9H.PHH;W!E;B`D9F@L("<^.G)A=R<L("1T
M96UP;F%M92D*)B8@*'!R:6YT("1F:"`D8V]N=&5N=',I"B8F("AC;&]S92`D
M9F@I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG("(D=&5M<&YA;64B.B`D(5T[
M"F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N
M86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE
M*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*
M:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]0
M4D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G
M;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R
M;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S
M=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI
M;7TI("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@
M)&9H+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF
M("@M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S
M>7-[7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@
M+UQ1)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E
M>&ES=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-
M4'T["B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M
M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L
M87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X
M97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE
M(BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*
M?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%
M3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?
M9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O
M9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@
M0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7
M:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA
M;64@/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?
M9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U
M8B!?<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK
M*R`]/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)
M6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'
M($-!0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R)005)?)%\B?3L*
M?0IF;W(@*'%W+R!435!$25(@5$5-4"!#3$5!3B!$14)51R`O*2!["B1%3E9[
M(E!!4E\D7R)](#T@)$5.5GLB4$%27T=,3T)!3%\D7R)](&EF(&5X:7-T<R`D
M14Y6>R)005)?1TQ/0D%,7R1?(GT["GT*:68@*"1%3E9[4$%27U1%35!]*2![
M"F1E;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*?0IS=6(@;W5T<R!["G)E='5R
M;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I;G0@)&QO9V9H(")`7UQN
M(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*
M<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E<"!D969I;F5D+"!M87`@
M)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X
M<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R
M;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF
M="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G
M<RD["F1I92!Q<5MP87(N<&PZ($-A;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P
M<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S
M("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I
M9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@:68@)$`[
M"GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I
M9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D
M.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?14Y$7U\*``!#04-(10``
M<&5R;'AS:2YC`````````/____\`````_____P`````!(T5G`````(FKS>\`
M````_MRZF`````!V5#(0`````/#ATL,````````````````!&P,[]````!T`
M``"`?___0`$``.""__]H`0``\(+__P@&````A?__$`$``/"%__^``0``P(;_
M_\P!``!0A___\`$``,"(__\L`@``P(G__V0"``"0BO__H`(``-",___L`@``
M((W__P@#``!0C?__'`,``!".__](`P``(([__UP#```PD/__O`,``&"0___8
M`P``H)'__Q`$````EO__7`0``'"6__]X!```D);__Y`$``"@E___[`0``)">
M__^<!0``L*#__]`%``"0H?__.`8```"X__^(!@``4+C__Z`&``#PN?__[`8`
M`$"\__\P!P```````!0``````````7I2``%X$`$;#`<(D`$'$!0````<````
MZ(/__R(``````````````!0``````````7I2``%X$`$;#`<(D`$``"0````<
M````.'[__V`#````#A!&#AA*#PMW"(``/QH[*C,D(@`````4````1````'"!
M__\(``````````````!(````7````&B$___,`````$(.$(\"0@X8C@-"#B"-
M!$(.*(P%00XPA@9!#CB#!T0.0`)L"@XX1`XP00XH0@X@0@X80@X00@X(20L`
M(````*@```#LA/__@P````!!#A"#`DH.L`$"<0H.$$$."$$+.````,P```!8
MA?__;`$```!"#A"-`D(.&(P#00X@A@1!#BB#!4<.T`%^"@XH00X@00X80@X0
M0@X(1PL`-`````@!``",AO__\@````!"#A",`DL.&(8#00X@@P1'#K"`!`*L
M"@X@00X800X00@X(2PL````X````0`$``%2'___0`````$(.$(T"1PX8C`-!
M#B"&!$0.*(,%40[`(`)D"@XH00X@00X80@X00@X(1PM(````?`$``.B'__\Q
M`@```$(.$(\"0@X8C@-"#B"-!$(.*(P%00XPA@9$#CB#!T<.4`,5`0H..$$.
M,$$.*$(.($(.&$(.$$(."$4+&````,@!``#<B?__2P````!!#A"#`FT."```
M`!````#D`0``$(K__R4`````````*````/@!```LBO__N0````!!#A"&`D$.
M&(,#1P[`0`*A"@X81`X000X(00L0````)`(``,"*__\%`````````%P````X
M`@``O(K__P("````0@X0CP)"#AB.`T(.((T$0@XHC`5+#C"&!D$..(,'2@[P
M(0)D"@XX00XP00XH0@X@0@X80@X00@X(1`L"N0[X(4\.@"):#O@A00[P(0``
M`!@```"8`@``;(S__R(`````00X0@P)<#@@````T````M`(``(",__\Q`0``
M`$$.$(8"00X8@P-'#K`@`N$*#AA!#A!!#@A$"UH*#AA(#A!!#@A-"T@```#L
M`@``B(W__UP$````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!D@..(,'1`Y0
M`P($"@XX30XP00XH0@X@0@X80@X00@X(10L8````.`,``)R1__]A`````$0.
M(`)0"@X(1`L`%````%0#``#PD?__'0````!$#A!8#@@`6````&P#``#XD?__
M"P$```!"#A"-`D(.&(P#2`X@A@1'#BB#!40.0`)""@XH1@X@00X80@X00@X(
M3`MD"@XH00X@00X80@X00@X(1@MA#DA)#E!C#DA!#D````"L````R`,``*R2
M___H!@```$(.$(\"4`X8C@-1#B"-!$D.*(P%00XPA@9!#CB#!T<.L`,#\@$.
MN`-A#L`#7PZX`T(.L`,";@H..$0.,$$.*$(.($(.&$(.$$(."$0+`T4!#K@#
M2P[``UX.N`-!#K`#7PZX`T0.P`-0#L@#2P[0`TL.L`,"Y@H..$0.,$$.*$(.
M($(.&$(.$$(."$4+`O4.N`-*#L`#1@ZX`T$.L`,``#````!X!```[)C__R`"
M````0@X0C`)(#AB&`T$.((,$1`XP`W$!"@X@00X800X00@X(1`LT````K`0`
M`-B:___;`````$$.$(8"1`X8@P-$#C`"BPH.&$$.$$$."$H+;`H.&$0.$$$.
M"$4+`"P```#D!```X'S__P8"````00X0A@)!#AB#`T0.4`-E`0H.&$,.$$$.
M"$$+`````$P````4!0``4)O__VH6````0@X0CP))#AB.`T(.((T$0@XHC`5!
M#C"&!D$..(,'1P[0!0-"%@H..$$.,$$.*$(.($(.&$(.$$(."$$+````%```
M`&0%``!PL?__10````!$#A`"0`X(2````'P%``"HL?__GP$```!"#A"/`D4.
M&(X#10X@C01"#BB,!40.,(8&10XX@P='#D`"Y0H..$$.,$$.*$(.($(.&$(.
M$$(."$,+`$````#(!0``_++__TL"````0@X0C@)&#AB-`T(.((P$00XHA@5$
M#C"#!@.;`0H.*$$.($(.&$(.$$(."$\+````````$`````P&```(M?__#```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````````(`F
M````````0"8````````!`````````,T"`````````0````````#=`@``````
M``P``````````"`````````-`````````.Q<````````&0````````#HNP``
M`````!L`````````"``````````:`````````/"[````````'``````````(
M`````````/7^_V\`````H`,````````%`````````#`-````````!@``````
M``"0!`````````H`````````7@0````````+`````````!@`````````%0``
M``````````````````,`````````^+T````````"`````````/@$````````
M%``````````'`````````!<`````````2!0````````'`````````,@2````
M````"`````````"``0````````D`````````&``````````>``````````@`
M````````^___;P`````!```(`````/[__V\`````2!(```````#___]O````
M``$`````````\/__;P````".$0```````/G__V\`````!```````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````/B[````````````````
M`````````````#8@````````1B````````!6(````````&8@````````=B``
M``````"&(````````)8@````````IB````````"V(````````,8@````````
MUB````````#F(````````/8@````````!B$````````6(0```````"8A````
M````-B$```````!&(0```````%8A````````9B$```````!V(0```````(8A
M````````EB$```````"F(0```````+8A````````QB$```````#6(0``````
M`.8A````````]B$````````&(@```````!8B````````)B(````````V(@``
M`````$8B````````5B(```````!F(@```````'8B````````AB(```````"6
M(@```````*8B````````MB(```````#&(@```````-8B````````YB(`````
M``#V(@````````8C````````%B,````````F(P```````#8C````````1B,`
M``````!6(P```````&8C````````=B,`````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````"E!!4BYP;0H``````````-AB
M````````1T-#.B`H1&5B:6%N(#$R+C,N,"TT*2`Q,BXS+C```"YS:'-T<G1A
M8@`N:6YT97)P`"YN;W1E+F=N=2YP<F]P97)T>0`N;F]T92YG;G4N8G5I;&0M
M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG
M;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E;&$N<&QT
M`"YI;FET`"YP;'0N9V]T`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE
M7VAD<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1Y;F%M
M:6,`+F1A=&$`+F)S<P`N8V]M;65N=```````````````````````````````
M``````````````````````````````````````````````````````````L`
M```!`````@`````````8`P```````!@#````````'```````````````````
M``$````````````````````3````!P````(`````````.`,````````X`P``
M`````"`````````````````````(````````````````````)@````<````"
M`````````%@#````````6`,````````D````````````````````!```````
M`````````````#D````'`````@````````!\`P```````'P#````````(```
M``````````````````0```````````````````!'````]O__;P(`````````
MH`,```````"@`P```````.P`````````!@`````````(````````````````
M````40````L````"`````````)`$````````D`0```````"@"`````````<`
M```!````"``````````8`````````%D````#`````@`````````P#0``````
M`#`-````````7@0```````````````````$```````````````````!A````
M____;P(`````````CA$```````".$0```````+@`````````!@`````````"
M``````````(`````````;@```/[__V\"`````````$@2````````2!(`````
M``"```````````<````!````"````````````````````'T````$`````@``
M``````#($@```````,@2````````@`$````````&``````````@`````````
M&`````````"'````!````$(`````````2!0```````!(%````````/@$````
M````!@```!<````(`````````!@`````````D0````$````&```````````@
M`````````"`````````7````````````````````!```````````````````
M`(P````!````!@`````````@(````````"`@````````8`,`````````````
M`````!``````````$`````````"7`````0````8`````````@",```````"`
M(P````````@````````````````````(``````````@`````````H`````$`
M```&`````````)`C````````D",```````!<.0``````````````````$```
M`````````````````*8````!````!@````````#L7````````.Q<````````
M"0````````````````````0```````````````````"L`````0````(`````
M`````&``````````8````````*!````````````````````0````````````
M````````M`````$````"`````````*"@````````H*````````#T````````
M````````````!````````````````````,(````!`````@````````"8H0``
M`````)BA````````4`8```````````````````@```````````````````#,
M````#@````,`````````Z+L```````#HJP````````@`````````````````
M```(``````````@`````````V`````\````#`````````/"[````````\*L`
M```````(````````````````````"``````````(`````````.0````&````
M`P````````#XNP```````/BK``````````(````````'``````````@`````
M````$`````````";`````0````,`````````^+T```````#XK0````````@"
M```````````````````(``````````@`````````[0````$````#````````
M``#``````````+`````````H````````````````````"```````````````
M`````/,````(`````P````````!`P````````"BP````````6```````````
M`````````"````````````````````#X`````0```#``````````````````
M```HL````````!X````````````````````!``````````$``````````0``
M``,`````````````````````````1K`````````!`0``````````````````
0`0``````````````````````
